@@ -100,6 +100,57 @@ class BitPackingTestCase(unittest.TestCase):
         self.assertRaises(IndexError, _libdna.slice_frombit2bytearray,
                          packed, 4, 3)
 
+    def testBit2complement_frombit2bytes(self):
+        string = b'ATACGCGGCT'+b'GATCGTAGCG'
+        vector = _libdna.bit2_frombytes(string)        
+        vector_compl = _libdna.bit2complement_frombit2bytes(vector)
+        self.assertEqual(len(vector), len(vector_compl))
+        string_compl = _libdna.byte_frombit2bytes(vector_compl)
+        self.assertEqual(b'TATGCGCCGACTAGCATCGC', string_compl)
+
+    def testBit2complement_frombit2bytearray(self):
+        string = b'ATACGCGGCT'+b'GATCGTAGCG'
+        vector = _libdna.bit2_frombytearray(bytearray(string))
+        vector_compl = _libdna.bit2complement_frombit2bytearray(vector)
+        self.assertEqual(len(vector), len(vector_compl))
+        string_compl = _libdna.byte_frombit2bytearray(vector_compl)
+        self.assertEqual(b'TATGCGCCGACTAGCATCGC', string_compl)
+
+    def testBit2reverse_frombit2bytes(self):
+        string = b'ATACGCGGCT'+b'GATCGTAGCG'
+        vector = _libdna.bit2_frombytes(string)        
+        vector_rev = _libdna.bit2reverse_frombit2bytes(vector)
+        self.assertEqual(len(vector), len(vector_rev))
+        string_rev = _libdna.byte_frombit2bytes(vector_rev)
+        self.assertEqual(b''.join(string[x] for x in range(len(string)-1, -1, -1)), string_rev)
+
+    def testBit2reverse_frombit2bytearray(self):
+        string = b'ATACGCGGCT'+b'GATCGTAGCG'
+        vector = _libdna.bit2_frombytearray(bytearray(string))
+        vector_rev = _libdna.bit2reverse_frombit2bytearray(vector)
+        self.assertEqual(len(vector), len(vector_rev))
+        string_rev = _libdna.byte_frombit2bytearray(vector_rev)
+        self.assertEqual(b''.join(string[x] for x in range(len(string)-1, -1, -1)), string_rev)
+
+    def testBit2reversecomplement_frombit2bytes(self):
+        string =    b'ATACGCGGCT'+b'GATCGTAGCG'
+        string_rc = b'TATGCGCCGA'+b'CTAGCATCGC'
+        string_rc = b''.join(string_rc[x] for x in range(len(string)-1, -1, -1))
+        vector = _libdna.bit2_frombytes(string)
+        vector_rc = _libdna.bit2reversecomplement_frombit2bytes(vector)
+        self.assertEqual(len(vector), len(vector_rc))
+        string_back = _libdna.byte_frombit2bytes(vector_rc)
+        self.assertEqual(string_rc, string_back)
+
+    def testBit2reversecomplement_frombit2bytearray(self):
+        string =    b'ATACGCGGCT'+b'GATCGTAGCG'
+        string_rc = b'TATGCGCCGA'+b'CTAGCATCGC'
+        string_rc = b''.join(string_rc[x] for x in range(len(string)-1, -1, -1))
+        vector = _libdna.bit2_frombytearray(bytearray(string))
+        vector_rc = _libdna.bit2reversecomplement_frombit2bytearray(vector)
+        self.assertEqual(len(vector), len(vector_rc))
+        string_back = _libdna.byte_frombit2bytearray(vector_rc)
+        self.assertEqual(string_rc, string_back)
 
         
 def suite():
