@@ -270,35 +270,45 @@ class XSQRunMetadata(h5py._hl.group.Group):
     A run can have several libraries sequenced at once.
     """
 
-class XSQInfo(OrderedDict):
-    __ats = (('tagdetails', lambda x: ', '.join(x.tags)), 
-             ('lanenumber', lambda x: x[0]),
-             ('hdfversion', lambda x: x[0]),
-             ('fileversion',lambda x: x[0]),
-             ('sequencingsamplename', lambda x: x[0]),
-             ('sequencingsampledescription', lambda x: x[0]),
-             ('runname',lambda x: x[0]))
+    def _getattr(self, attr):
+        try:
+            return self.attrs[attr]
+        except KeyError:
+            return [None, ]
 
     def _tagdetails_get(self):
-        return XSQTagDetailsList(self[u'TagDetails'].id)
+        return 
 
-    tagdetails = property(_tagdetails_get, None, None,
+    tagdetails = property(lambda self: XSQTagDetailsList(self[u'TagDetails']).tags, 
+                          None, None,
                           'Tag details')
-    lanenumber = property(lambda self: self.attrs[u'LaneNumber'], None, None,
+    lanenumber = property(lambda self: self._getattr(u'LaneNumber')[0], None, None,
                           'Lane number')
-    librarytype = property(lambda self: self.attrs[u'LibraryType'], None, None,
+    librarytype = property(lambda self: self._getattr(u'LibraryType')[0], None, None,
                            'Library type')
-    hdfversion = property(lambda self: self.attrs[u'HDFVersion'], None, None,
+    hdfversion = property(lambda self: self._getattr(u'HDFVersion')[0], None, None,
                           'Version of the HDF5 file')
-    fileversion = property(lambda self: self.attrs[u'FileVersion'], None, None,
+    fileversion = property(lambda self: self._getattr(u'FileVersion')[0], None, None,
                            'Version of the XSQ file')
-    sequencingsamplename = property(lambda self: self.attrs[u'SequencingSampleName'], None, None,
-                                    'Sequencing sample name')
-    sequencingsampledescription = property(lambda self: self.attrs[u'SequencingSampleDescription'], None, None,
+    sequencingsamplename = property(lambda self: self._getattr(u'SequencingSampleName')[0], 
+                                    None, None, 'Sequencing sample name')
+    sequencingsampledescription = property(lambda self: self._getattr(u'SequencingSampleDescription')[0], None, None,
                                            'Sequencing sample description')
-    runname = property(lambda self: self.attrs[u'RunName'], None, None,
+    runname = property(lambda self: self._getattr(u'RunName')[0], None, None,
                        'Name for the run')
 
+
+class XSQInfo(OrderedDict):
+    __ats = (('tagdetails', lambda x: ', '.join(x.tags)), 
+             ('lanenumber', lambda x: x),
+             ('hdfversion', lambda x: x),
+             ('fileversion',lambda x: x),
+             ('sequencingsamplename', lambda x: x),
+             ('sequencingsampledescription', lambda x: x),
+             ('runname',lambda x: x))
+
+    def __init__(self):
+        raise Error('')
     @classmethod
     def fromxsqfile_toordict(cls, xsqfile):
         assert(isinstance(xsqfile, XSQFile))
@@ -307,15 +317,18 @@ class XSQInfo(OrderedDict):
             mtd = xsqfile.run_metadata
         except KeyError, ke:
             mtd = None
-        
+ 
         for at, fun in cls.__ats:
-            field = getattr(cls, at).__doc__
+            field = getattr(XSQRunMetadata, at).__doc__
+            if mtd is None:
+                res[field] = 'Missing'
+                continue
             try:
                 tmp = getattr(mtd, at)
                 #import pdb; pdb.set_trace()
                 value = str(fun(tmp))
             except AttributeError:
-                value = 'NA'
+                value = 'Error'
             res[field] = value
         return res
         
@@ -619,7 +632,7 @@ def make_htmlreport(xsqfile, directory = '.', verbose = True,
             'sample_percent': sample_percent})
 
     html_fn = os.path.join(directory, 
-                           'fastqual_%s_%s.html' % (os.path.basename(xsqfile.filename), fragment))
+                           'fastqual_%s.html' % (os.path.basename(xsqfile.filename)))
     if verbose:
         sys.stdout.write('Creating file %s...' % html_fn)
     f = file(html_fn, mode = 'w')
